.. _examples:

Examples
========


Simple signal viewer
--------------------

.. image:: img/trace_viewer_example.png

:download:`trace_viewer.py <../examples/trace_viewer.py>`

.. literalinclude:: ../examples/trace_viewer.py


Signal viewer with data source
------------------------------

:download:`trace_viewer_datasource.py <../examples/trace_viewer_datasource.py>`

.. literalinclude:: ../examples/trace_viewer_datasource.py


Signal viewer with markers
--------------------------

.. image:: img/trace_viewer_with_marker_example.png

:download:`trace_viewer_with_marker.py <../examples/trace_viewer_with_marker.py>`

.. literalinclude:: ../examples/trace_viewer_with_marker.py


Time-frequency viewer
---------------------

.. image:: img/timefreq_viewer_example.png

:download:`timefreq_viewer.py <../examples/timefreq_viewer.py>`

.. literalinclude:: ../examples/timefreq_viewer.py

Spectrogram viewer
------------------

.. image:: img/spectrogram_viewer_example.png

:download:`spectrogram_viewer.py <../examples/spectrogram_viewer.py>`

.. literalinclude:: ../examples/spectrogram_viewer.py


Spike train viewer
------------------

.. image:: img/spikes_viewer_example.png

:download:`spikes_viewer.py <../examples/spikes_viewer.py>`

.. literalinclude:: ../examples/spikes_viewer.py


Epoch viewer
------------

.. image:: img/event_epoch_viewer_example.png

:download:`event_epoch_viewer.py <../examples/event_epoch_viewer.py>`

.. literalinclude:: ../examples/event_epoch_viewer.py


Epoch encoder
-------------

.. image:: img/epoch_encoder_example.png

:download:`epoch_encoder.py <../examples/epoch_encoder.py>`

.. literalinclude:: ../examples/epoch_encoder.py


Mixed viewer
------------

.. image:: img/mixed_viewer_example.png

:download:`mixed_viewer.py <../examples/mixed_viewer.py>`

.. literalinclude:: ../examples/mixed_viewer.py


Viewers from Neo objects
------------------------

.. image:: img/viewers_with_neo_objects_example.png

:download:`viewers_with_neo_objects.py <../examples/viewers_with_neo_objects.py>`

.. literalinclude:: ../examples/viewers_with_neo_objects.py


Viewers for SpikeInterface objects
----------------------------------

.. image:: img/viewers_with_spikeinterface_objects.png

:download:`viewers_with_spikeinterface_objects.py <../examples/viewers_with_spikeinterface_objects.py>`

.. literalinclude:: ../examples/viewers_with_spikeinterface_objects.py
